@@ -512,6 +512,33 @@ org_mozdev_compactHeader.pane = function() {
       }
     }
 
+    var enigmailBox = document.getElementById("enigmailBox");
+
+    if (enigmailBox != null) {
+      if (gCoheCollapsedHeaderViewMode) {
+        if (cohePrefBranch.getBoolPref("headersize.twolineview")) {
+          var parent = document.getElementById("CompactHeader_collapsed2LHeadersBox");
+          var refElement = document.getElementById("CompactHeader_collapsed2LHeaderViewFirstLine");
+          if (parent != null && refElement != null) {
+            parent.insertBefore(enigmailBox, refElement);
+          }
+        } else {
+          var parent = document.getElementById("CompactHeader_collapsed1LHeadersBox");
+          var refElement = document.getElementById("CompactHeader_collapsed1LHeaderViewFirstLine");
+          if (parent != null && refElement != null) {
+            parent.insertBefore(enigmailBox, refElement);
+          }
+        }
+      }
+      else {
+        var parent = document.getElementById("expandedHeadersBox");
+        var refElement = document.getElementById("expandedHeadersTopBox");
+        if (parent != null && refElement != null) {
+          parent.insertBefore(enigmailBox, refElement);
+        }
+      }
+    }
+
     org_mozdev_compactHeader.messenger.loadToolboxData();
 
     if (gCoheCollapsedHeaderViewMode) {
@@ -863,7 +890,11 @@ org_mozdev_compactHeader.pane = function() {
   }
 
   function darkenColor(color) {
-    var digits = /(.*?)rgb\((\d+), (\d+), (\d+)\)/.exec(color);
+    if (color === "transparent") {
+      return color;
+    }
+
+    var digits = /(.*?)rgba?\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+))?\)/.exec(color);
 
     var red = parseInt(digits[2]);
     var green = parseInt(digits[3]);
