@@ -3,6 +3,11 @@ pref("extensions.CompactHeader.headersize.linkify", false);
 pref("extensions.CompactHeader.headersize.addressstyle", false);
 pref("extensions.CompactHeader.headersize.flatButtons", false);
 
+pref("extensions.CompactHeader.toolbox.position", "top");
+
+pref("extensions.CompactHeader.header.doubleclick", true);
+pref("extensions.CompactHeader.header.darkenonfocus", false);
+
 pref("extensions.CompactHeader.version", "0");
 pref("extensions.CompactHeader.firstrun", true);
 pref("extensions.CompactHeader.debugLevel", 1);
